==> wink-statistics-1.1.1.tgz: package/README.md <==
# wink-statistics

Fast and Numerically Stable Statistical Analysis Utilities

### [![Build Status](https://api.travis-ci.org/winkjs/wink-statistics.svg?branch=master)](https://travis-ci.org/winkjs/wink-statistics) [![Coverage Status](https://coveralls.io/repos/github/winkjs/wink-statistics/badge.svg?branch=master)](https://coveralls.io/github/winkjs/wink-statistics?branch=master) [![Inline docs](http://inch-ci.org/github/winkjs/wink-statistics.svg?branch=master)](http://inch-ci.org/github/winkjs/wink-statistics) [![dependencies Status](https://david-dm.org/winkjs/wink-statistics/status.svg)](https://david-dm.org/winkjs/wink-statistics) [![devDependencies Status](https://david-dm.org/winkjs/wink-statistics/dev-status.svg)](https://david-dm.org/winkjs/wink-statistics?type=dev) [![Gitter](https://img.shields.io/gitter/room/nwjs/nw.js.svg)](https://gitter.im/winkjs/Lobby)

<img align="right" src="https://decisively.github.io/wink-logos/logo-title.png" width="100px" >

Perform fast and numerically stable statistical analysis using **`wink-statistics`**. It is a part of [wink](http://winkjs.org/) — a growing family of high quality packages for Statistical Analysis, Natural Language Processing and Machine Learning in NodeJS.

Summarize, Discover and Analyze data with it's rich set of features:

1. Analyze both continuous and categorical data.

2. Handles real-time stream of data and incrementally compute required statistic that usually would take more than one pass over the data.

3. Minimizes data preprocessing by handling array of data structures containing numerical values, e.g. array of objects.


### Installation

Use [npm](https://www.npmjs.com/package/wink-statistics) to install:

    npm install wink-statistics --save

### API
Check out the [statistics API documentation](http://winkjs.org/wink-statistics/) to learn more.

### Need Help?

If you spot a bug and the same has not yet been reported, raise a new [issue](https://github.com/winkjs/wink-statistics/issues) or consider fixing it and sending a pull request.

### Copyright & License

**wink-statistics** is copyright 2017-18 [GRAYPE Systems Private Limited](http://graype.in/).

It is licensed under the under the terms of the GNU Affero General Public License as published by the Free
Software Foundation, version 3 of the License.

==> wink-statistics-1.3.0.tgz: package/README.md <==
# wink-statistics

Fast and Numerically Stable Statistical Analysis Utilities

### [![Build Status](https://api.travis-ci.org/winkjs/wink-statistics.svg?branch=master)](https://travis-ci.org/winkjs/wink-statistics) [![Coverage Status](https://coveralls.io/repos/github/winkjs/wink-statistics/badge.svg?branch=master)](https://coveralls.io/github/winkjs/wink-statistics?branch=master) [![Inline docs](http://inch-ci.org/github/winkjs/wink-statistics.svg?branch=master)](http://inch-ci.org/github/winkjs/wink-statistics) [![dependencies Status](https://david-dm.org/winkjs/wink-statistics/status.svg)](https://david-dm.org/winkjs/wink-statistics) [![devDependencies Status](https://david-dm.org/winkjs/wink-statistics/dev-status.svg)](https://david-dm.org/winkjs/wink-statistics?type=dev) [![Gitter](https://img.shields.io/gitter/room/nwjs/nw.js.svg)](https://gitter.im/winkjs/Lobby)

<img align="right" src="https://decisively.github.io/wink-logos/logo-title.png" width="100px" >

Perform fast and numerically stable statistical analysis using **`wink-statistics`**. It is a part of [wink](http://winkjs.org/) — a growing family of high quality packages for Statistical Analysis, Natural Language Processing and Machine Learning in NodeJS.

Summarize, Discover and Analyze data with it's rich set of features:

1. Analyze both continuous and categorical data.

2. Handles real-time stream of data and incrementally compute required statistic that usually would take more than one pass over the data as in **standard deviation** or **simple linear regression**.

3. Minimizes data preprocessing by handling array of data structures containing numerical values, e.g. array of objects.


### Installation

Use [npm](https://www.npmjs.com/package/wink-statistics) to install:

    npm install wink-statistics --save

### API
Check out the [statistics API documentation](http://winkjs.org/wink-statistics/) to learn more.

### Need Help?

If you spot a bug and the same has not yet been reported, raise a new [issue](https://github.com/winkjs/wink-statistics/issues) or consider fixing it and sending a pull request.

### Copyright & License

**wink-statistics** is copyright 2017-18 [GRAYPE Systems Private Limited](http://graype.in/).

It is licensed under the under the terms of the GNU Affero General Public License as published by the Free
Software Foundation, version 3 of the License.
